@@ -2,9 +2,10 @@ class Config:
     defaults = {
         "user_input_valid_color": 3,
         "user_input_invalid_color": 2,
-        "reference_text_color": 8,
-        "stats_template": "\n\nwpm: {stats.wpm:0.2f}\ntime: {stats.total_seconds:0.2f}s",
+        "reference_text_color": 9,
+        "stats_template": "wpm: {stats.wpm:0.2f}, time: {stats.total_seconds:0.2f}s",
         "stats_color": 5,
+        "stats_position": "top",
         "summary_template": (
             "WPM: {stats.wpm:0.2f}\n"
             "CPM: {stats.cpm:0.2f}\n"
@@ -21,8 +22,8 @@ class Config:
             "accuracy: {stats.accuracy:0.2f}%"
         ),
         "summary_datafile": "~/.cache/fasttyper/datafile.csv",
-        "top_margin_percentage": 30,
-        "left_margin_percentage": 10,
+        "top_margin_percentage": 40,
+        "left_margin_percentage": 35,
         "lines_on_screen": 3,
     }
 
