@@ -6,9 +6,15 @@ class Interface:
         self.application = application
         self.components = components
         self.no_cursor = no_cursor
+        self.colors = True
 
     def init_colors(self):
-        assert curses.has_colors()
+        try:
+            assert curses.has_colors()
+        except AssertionError:
+            self.colors = False
+            return
+
         curses.start_color()
         curses.use_default_colors()
 
@@ -16,13 +22,12 @@ class Interface:
             curses.init_pair(i + 1, i, -1)
 
     def init(self, screen):
+        screen.clear()
         self.init_colors()
 
     def update(self, screen):
-        screen.clear()
         for component in self.components:
             component.paint(screen, self.application)
-        screen.refresh()
 
     def __call__(self, screen):
         """
